parade.notify package
=====================

Submodules
----------

parade.notify.default module
----------------------------

.. automodule:: parade.notify.default
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: parade.notify
    :members:
    :undoc-members:
    :show-inheritance:
